Exception: Brut::Framework::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/brut/framework/errors.rb

Overview

Base class for errors thrown by Brut classes. Generally, Brut will not create its own version of an error that exists in the standard library, e.g. ‘ArgumentError`, so this is only a base class for Brut-specific error conditions.