Module: Brut::FrontEnd::Components
- Extended by:
- Phlex::Kit
- Defined in:
- lib/brut/front_end/component.rb,
lib/brut/front_end/components/input.rb
Overview
Namespace for Brut-provided components that are of general use to any web app. Also extends [‘Phlex:::Kit`](www.phlex.fun/components/kits.html), meaning you can include this module in your pages and components to be able to create Brut’s components without ‘.new` or without the full classname:
Defined Under Namespace
Modules: Inputs Classes: ConstraintViolations, FormTag, I18nTranslations, Input, LocaleDetection, PageIdentifier, TimeTag, Traceparent