Module: Brut::SpecSupport::HandlerSupport
- Includes:
- ClockSupport, FlashSupport, SessionSupport
- Defined in:
- lib/brut/spec_support/handler_support.rb
Overview
Convienience methods for testing handlers. When testing handlers, the following matchers may be useful:
-
‘have_redirected_to` to check that the handler redirected to a give URI
-
‘have_generated` to check that the handler rendered a specific page
-
‘have_returned_http_status` to check that the handler returned an HTTP status
Method Summary
Methods included from SessionSupport
Methods included from ClockSupport
#clock_at, #clock_in_timezone_at, #real_clock